@@ -3,11 +3,12 @@ from enum import Enum, unique
 
 
 @unique
-class config(Enum):
+class Config(Enum):
     DATA_DIR = "data_dir"
     OUTPUT_DIR = "output_dir"
     MODE = "mode"
     YEAR = "year"
+    FILE_TYPE = "file_type"
 
 
 ONE_DAY = timedelta(days=1)
