@@ -1,9 +1,8 @@
 import os
-from datetime import datetime
 
 import click
 
-from yearmaps.constant import config
+from yearmaps.constant import Config
 from yearmaps.providers import providers
 from yearmaps.utils.file import default_data_dir
 
@@ -13,21 +12,27 @@ from yearmaps.utils.file import default_data_dir
               help='Directory to store datas')
 @click.option('--output-dir', '-o', default=os.getcwd(), type=str, show_default=True,
               help='Directory to store output')
+@click.option('--file-type', '-f', default='svg', type=click.Choice(['svg', 'png']), show_default=True,
+              help='File type to export')
 @click.option('--mode', '-m', default='till_now', type=click.Choice(['till_now', 'year']), show_default=True,
               help='Generate mode of the program')
-@click.option('--year', '-y', default=datetime.now().year, type=int, show_default=True,
-              help='Year to generate, this options depends on mode=year')
+@click.option('--year', '-y', default=1900, type=int, show_default=True,
+              help='Year to generate, this options will override mode to "year"')
 @click.pass_context
-def cli(ctx: click.Context, data_dir: str, output_dir: str, mode: str, year: int):
+def cli(ctx: click.Context, data_dir: str, output_dir: str, file_type: str, mode: str, year: int):
     ctx.ensure_object(dict)
     obj = ctx.obj
-    obj[config.DATA_DIR] = data_dir
-    obj[config.OUTPUT_DIR] = output_dir
+    obj[Config.DATA_DIR] = data_dir
+    obj[Config.OUTPUT_DIR] = output_dir
+    obj[Config.FILE_TYPE] = file_type
+    if year != 1900:
+        if mode == 'till_now':
+            mode = 'year'
     if mode == 'year':
-        obj[config.MODE] = mode
-        obj[config.YEAR] = year
+        obj[Config.MODE] = mode
+        obj[Config.YEAR] = year
     else:
-        obj[config.MODE] = mode
+        obj[Config.MODE] = mode
 
 
 def main():
